Module traits

Module traits 

Traits

Crud
Common Create, Read, Update, and Delete behaviors. This trait requires that Schema and FromRow are implemented for Self.
Schema
Database schema information about a struct implementing sqlx FromRow. Schema defines methods for accessing the derived database schema and query information.

Type Aliases

CrudFut
Type alias for methods returning a single element. The future resolves to and Result<T, sqlx::Error>.
CrudStream
Type alias for a Stream returning items of type Result<T, sqlxError>.
TryCollectFut
Type alias for a TryCollect future that resolves to Result<Vec<T>, sqlx::Error>.